@@ -20,8 +20,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 #ifndef APC_H
@@ -147,9 +147,14 @@
 
 /* System includes conditionally included */
 
-/* Pull in our local copy because the library does not have correct protos */
 #ifdef HAVE_LIBWRAP
-# include "tcpd.h"
+# ifdef __cplusplus
+   extern "C" {
+# endif
+# include <tcpd.h>
+# ifdef __cplusplus
+   };
+# endif
 #endif
 
 #endif
