@@ -20,8 +20,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 #include "apc.h"
@@ -178,7 +178,7 @@ static int write_file(char *buf)
    static int out_fd = -1;
 
    if (out_fd == -1) {
-      out_fd = open("apctest.output", O_WRONLY | O_CREAT | O_APPEND, 0644);
+      out_fd = open("apctest.output", O_WRONLY | O_CREAT | O_APPEND | O_CLOEXEC, 0644);
       if (out_fd < 0) {
          printf("Could not create apctest.output: %s\n", strerror(errno));
          return -1;
@@ -509,7 +509,7 @@ static void test1(void)
         "The UPS should be plugged in to the power, and the serial cable\n"
         "should be connected to the computer.\n\n"
         "Please enter any character when ready to continue: ");
-   fgetc(stdin);
+   (void)fgetc(stdin);
    pmsg("\n");
 
    normal = test_bits(0);
@@ -524,7 +524,7 @@ static void test2(void)
    pmsg("\nFor the second test, the UPS should be plugged in to the power, \n"
         "but the serial port should be DISCONNECTED from the computer.\n\n"
         "Please enter any character when ready to continue: ");
-   fgetc(stdin);
+   (void)fgetc(stdin);
    pmsg("\n");
 
    no_cable = test_bits(0);
@@ -539,7 +539,7 @@ static void test3(void)
    pmsg("\nFor the third test, the serial cable should be plugged\n"
         "back into the UPS, but the AC power plug to the UPS should be DISCONNECTED.\n\n"
         "Please enter any character when ready to continue: ");
-   fgetc(stdin);
+   (void)fgetc(stdin);
    pmsg("\n");
 
    no_power = test_bits(0);
@@ -567,7 +567,7 @@ static void test4(void)
         "the test. If not, hit control-C to stop the program\n\n"
         "PLEASE DO NOT RUN THIS TEST WITH A COMPUTER CONNECTED TO YOUR UPS!!!\n\n"
         "Please enter any character when ready to continue: ");
-   fgetc(stdin);
+   (void)fgetc(stdin);
    pmsg("\n");
 
    low_batt = no_power;
@@ -614,7 +614,7 @@ static void test5(void)
         "the very moment that the UPS powers down.\n\n"
         "PLEASE DO NOT RUN THIS TEST WITH A COMPUTER CONNECTED TO YOUR UPS!!!\n\n"
         "Please enter any character when ready to continue: ");
-   fgetc(stdin);
+   (void)fgetc(stdin);
    pmsg("\n");
 
    pmsg("Start test 5:\n");
@@ -654,7 +654,7 @@ static void test6(void)
         "AC power plug to the UPS should be DISCONNECTED.\n\n"
         "PLEASE DO NOT RUN THIS TEST WITH A COMPUTER CONNECTED TO YOUR UPS!!!\n\n"
         "Please enter any character when ready to continue: ");
-   fgetc(stdin);
+   (void)fgetc(stdin);
    pmsg("\n");
 
    if (ioctl(ups->fd, TIOCMGET, &bits) < 0) {
@@ -1599,9 +1599,9 @@ static void usb_set_xferv(int lowhigh)
       // Give write a chance to work, then read new value
       sleep(1);
       result = 0;
-      usb_read_int_from_ups(ups, ci, &result);
-
-      if (result != newval) {
+      if (!usb_read_int_from_ups(ups, ci, &result))
+         pmsg("FAILED to set new %s transfer voltage.\n\n", text);
+      else if (result != newval) {
          pmsg("FAILED to set new %s transfer voltage.\n\n"
               "This is probably because you entered a value that is out-of-range\n"
               "for your UPS. The acceptable range of values varies based on UPS\n"
@@ -1676,21 +1676,27 @@ static void usb_set_sens(void)
    /* Delay needed for readback to work */
    sleep(1);
 
-   usb_read_int_from_ups(ups, CI_SENS, &result);
-   pmsg("New sensitivity setting: ");
-   switch(result) {
-   case 0:
-      pmsg("LOW\n");
-      break;
-   case 1:
-      pmsg("MEDIUM\n");
-      break;
-   case 2:
-      pmsg("HIGH\n");
-      break;
-   default:
-      pmsg("UNKNOWN\n");
-      break;
+   if (!usb_read_int_from_ups(ups, CI_SENS, &result))
+   {
+      pmsg("FAILED to set sensitivity\n");
+   }
+   else
+   {
+      pmsg("New sensitivity setting: ");
+      switch(result) {
+      case 0:
+         pmsg("LOW\n");
+         break;
+      case 1:
+         pmsg("MEDIUM\n");
+         break;
+      case 2:
+         pmsg("HIGH\n");
+         break;
+      default:
+         pmsg("UNKNOWN\n");
+         break;
+      }
    }
 }
 
@@ -1749,18 +1755,24 @@ static void usb_set_alarm(void)
    /* Delay needed for readback to work */
    sleep(1);
 
-   usb_read_int_from_ups(ups, CI_DALARM, &result);
-   pmsg("New alarm setting: ");
-   switch(result) {
-   case 1:
-      pmsg("DISABLED\n");
-      break;
-   case 2:
-      pmsg("ENABLED\n");
-      break;
-   default:
-      pmsg("UNKNOWN\n");
-      break;
+   if (!usb_read_int_from_ups(ups, CI_DALARM, &result))
+   {
+      pmsg("FAILED to set alarm\n");
+   }
+   else
+   {
+      pmsg("New alarm setting: ");
+      switch(result) {
+      case 1:
+         pmsg("DISABLED\n");
+         break;
+      case 2:
+         pmsg("ENABLED\n");
+         break;
+      default:
+         pmsg("UNKNOWN\n");
+         break;
+      }
    }
 }
 
@@ -1772,7 +1784,7 @@ static void usb_kill_power_test(void)
         "PLEASE DO NOT RUN THIS TEST WITH A COMPUTER CONNECTED TO YOUR UPS!!!\n\n"
         "Please enter any character when ready to continue: ");
 
-   fgetc(stdin);
+   (void)fgetc(stdin);
    pmsg("\n");
 
    ptime();
@@ -2539,7 +2551,7 @@ static void modbus_kill_power_test(void)
         "PLEASE DO NOT RUN THIS TEST WITH A COMPUTER CONNECTED TO YOUR UPS!!!\n\n"
         "Please enter any character when ready to continue: ");
 
-   fgetc(stdin);
+   (void)fgetc(stdin);
    pmsg("\n");
 
    ptime();
