@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 #ifndef _MODBUSUSBCOMM_H
@@ -41,6 +41,8 @@ private:
 
    virtual bool ModbusTx(const ModbusFrame *frm, unsigned int sz);
    virtual bool ModbusRx(ModbusFrame *frm, unsigned int *sz);
+   bool WaitIdle();
+   static uint64_t GetTod();
 
    static const unsigned MODBUS_USB_REPORT_SIZE = 64;
    static const unsigned MODBUS_USB_REPORT_MAX_FRAME_SIZE = 
