@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 /*
@@ -58,7 +58,8 @@ const ModbusUpsDriver::CiInfo ModbusUpsDriver::CI_TABLE[] =
    { CI_NOMOUTV,         false,   &REG_OUTPUT_VOLTAGE_SETTING       },
    { CI_REVNO,           false,   &REG_FW_VERSION                   },
    { CI_BUPSelfTest,     false,   &REG_MODBUS_MAP_ID                }, // Purposely after CI_REVNO
-   { CI_NOMPOWER,        false,   &REG_OUTPUT_REAL_POWER_RATING     }, // TODO: Decide real or apparent power
+   { CI_NOMPOWER,        false,   &REG_OUTPUT_REAL_POWER_RATING     },
+   { CI_NomApparent,     false,   &REG_OUTPUT_APPARENT_POWER_RATING },
    { CI_DSHUTD,          false,   &REG_MOG_TURN_OFF_COUNT_SETTING   },
    { CI_DWAKE,           false,   &REG_MOG_TURN_ON_COUNT_SETTING    },
 // { CI_NOMBATTV,        false,   upsAdvBatteryNominalVoltage,
@@ -74,6 +75,7 @@ const ModbusUpsDriver::CiInfo ModbusUpsDriver::CI_TABLE[] =
 
    { CI_VLINE,           true,    &REG_INPUT_0_VOLTAGE              },
    { CI_VOUT,            true,    &REG_OUTPUT_0_VOLTAGE             },
+   { CI_OutputCurrent,   true,    &REG_OUTPUT_0_CURRENT             },
    { CI_VBATT,           true,    &REG_BATTERY_VOLTAGE              },
    { CI_FREQ,            true,    &REG_OUTPUT_FREQUENCY             },
    { CI_ITEMP,           true,    &REG_BATTERY_TEMPERATURE          },
@@ -88,7 +90,8 @@ const ModbusUpsDriver::CiInfo ModbusUpsDriver::CI_TABLE[] =
    { CI_BatteryPresent,  true,    &REG_BATTERY_SYSTEM_ERROR         },
    { CI_Boost,           true,    &REG_INPUT_STATUS                 },
    { CI_Trim,            true,    &REG_INPUT_STATUS                 },
-   { CI_LOAD,            true,    &REG_OUTPUT_0_REAL_POWER          }, // TODO: Decide real or apparent power
+   { CI_LOAD,            true,    &REG_OUTPUT_0_REAL_POWER_PCT      },
+   { CI_LoadApparent,    true,    &REG_OUTPUT_0_APPARENT_POWER_PCT  },
    { CI_LowBattery,      true,    &REG_SIMPLE_SIGNALLING_STATUS     },
 // { CI_VMIN,            true,    upsAdvInputMinLineVoltage
 // { CI_VMAX,            true,    upsAdvInputMaxLineVoltage
@@ -102,6 +105,7 @@ const ModbusUpsDriver::CiInfo ModbusUpsDriver::CI_TABLE[] =
 
 ModbusUpsDriver::ModbusUpsDriver(UPSINFO *ups) :
    UpsDriver(ups),
+   _commlost_time(0),
    _comm(NULL)
 {
 }
@@ -130,7 +134,7 @@ bool ModbusUpsDriver::check_state()
       }
 
       // Try to recover from commlost by reopening port
-      ret = !_ups->is_commlost() || Open();
+      ret = !_ups->is_commlost() || _comm->Open(_ups->device);
       if (ret)
       {
          // Remember current online/onbatt state
@@ -177,6 +181,7 @@ bool ModbusUpsDriver::check_state()
             _commlost_time = now;
             _ups->set_commlost();
             generate_event(_ups, CMDCOMMFAILURE);
+            _comm->Close();
          }
       }
 
@@ -374,6 +379,10 @@ bool ModbusUpsDriver::UpdateCi(const CiInfo *info)
       Dmsg(80, "Got CI_NOMPOWER: %llu\n", uint);
       _ups->NomPower = uint;
       break;
+   case CI_NomApparent:
+      Dmsg(80, "Got CI_NomApparent: %llu\n", uint);
+      _ups->NomApparentPower = uint;
+      break;
    case CI_DSHUTD:
       Dmsg(80, "Got CI_DSHUTD: %lld\n", sint);
       _ups->dshutd = sint;
@@ -411,6 +420,10 @@ bool ModbusUpsDriver::UpdateCi(const CiInfo *info)
       Dmsg(80, "Got CI_LOAD: %f\n", dbl);
       _ups->UPSLoad = dbl;
       break;
+   case CI_LoadApparent:
+      Dmsg(80, "Got CI_LoadApparent: %f\n", dbl);
+      _ups->LoadApparent = dbl;
+      break;
    case CI_VLINE:
       Dmsg(80, "Got CI_VLINE: %f\n", dbl);
       _ups->LineVoltage = dbl;
@@ -419,6 +432,10 @@ bool ModbusUpsDriver::UpdateCi(const CiInfo *info)
       Dmsg(80, "Got CI_VOUT: %f\n", dbl);
       _ups->OutputVoltage = dbl;
       break;
+   case CI_OutputCurrent:
+      Dmsg(80, "Got CI_OutputCurrent: %f\n", dbl);
+      _ups->OutputCurrent = dbl;
+      break;
    case CI_VBATT:
       Dmsg(80, "Got CI_VBATT: %f\n", dbl);
       _ups->BattVoltage = dbl;
