@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 #include "apc.h"
@@ -648,7 +648,7 @@ bool PcnetUpsDriver::Open()
       }
    }
 
-   _fd = socket(PF_INET, SOCK_DGRAM, 0);
+   _fd = socket_cloexec(PF_INET, SOCK_DGRAM, 0);
    if (_fd == INVALID_SOCKET)
       Error_abort("Cannot create socket (%d)\n", errno);
 
@@ -801,7 +801,7 @@ bool PcnetUpsDriver::kill_power()
    }
 
    /* Open a TCP stream to the UPS */
-   s = socket(PF_INET, SOCK_STREAM, 0);
+   s = socket_cloexec(PF_INET, SOCK_STREAM, 0);
    if (s == INVALID_SOCKET) {
       Dmsg(100, "pcnet_ups_kill_power: Unable to open socket: %s\n",
          strerror(errno));
