@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 #include "apc.h"
@@ -81,7 +81,7 @@ bool SnmpEngine::Open(const char *host, unsigned short port, const char *comm)
    }
 
    // Get a UDP socket
-   _socket = socket(PF_INET, SOCK_DGRAM, 0);
+   _socket = socket_cloexec(PF_INET, SOCK_DGRAM, 0);
    if (_socket == INVALID_SOCKET)
    {
       perror("socket");
@@ -108,7 +108,7 @@ bool SnmpEngine::Open(const char *host, unsigned short port, const char *comm)
 
 bool SnmpEngine::EnableTraps()
 {
-   _trapsock = socket(PF_INET, SOCK_DGRAM, 0);
+   _trapsock = socket_cloexec(PF_INET, SOCK_DGRAM, 0);
    if (_trapsock == INVALID_SOCKET)
    {
       perror("socket");
