@@ -24,8 +24,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 /*
@@ -94,7 +94,7 @@ int LinuxUsbUpsDriver::open_device(const char *dev)
    Dmsg(200, "Attempting to open \"%s\"\n", dev);
 
    /* Open the device port */
-   fd = open(dev, O_RDWR | O_NOCTTY);
+   fd = open(dev, O_RDWR | O_NOCTTY | O_CLOEXEC);
    if (fd >= 0) {
       /* Check for the UPS application HID usage */
       for (i = 0; (ret = ioctl(fd, HIDIOCAPPLICATION, i)) > 0; i++) {
@@ -125,14 +125,17 @@ void LinuxUsbUpsDriver::bind_upses()
 #ifdef USBDEVFS_CONNECT
    // Find all USB devices in usbfs
    glob_t g;
-   if (glob("/proc/bus/usb/[0-9][0-9][0-9]/[0-9][0-9][0-9]", 0, NULL, &g))
+   if (glob("/proc/bus/usb/[0-9][0-9][0-9]/[0-9][0-9][0-9]", 0, NULL, &g) &&
+      glob("/dev/bus/usb/[0-9][0-9][0-9]/[0-9][0-9][0-9]", 0, NULL, &g))
+   {
       return;
+   }
 
    // Iterate over all USB devices...
    for (size_t i = 0; i < g.gl_pathc; ++i)
    {
       // Open the device in usbfs
-      int fd = open(g.gl_pathv[i], O_RDWR);
+      int fd = open(g.gl_pathv[i], O_RDWR|O_CLOEXEC);
       if (fd == -1)
          continue;
 
@@ -696,7 +699,8 @@ bool LinuxUsbUpsDriver::pusb_ups_get_capabilities()
                if (ioctl(_fd, HIDIOCGUCODE, &uref) < 0)
                   continue;
 
-               ioctl(_fd, HIDIOCGUSAGE, &uref);
+               if (ioctl(_fd, HIDIOCGUSAGE, &uref) < 0)
+                  continue;
 
                /*
                 * We've got a UPS usage entry, now walk down our
