@@ -21,8 +21,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 #include "apc.h"
@@ -1114,7 +1114,7 @@ bool UsbUpsDriver::kill_power()
     * at least place a harmless command in it. We use CI_STATUS as that is a
     * usage any UPS should have.
     */
-   read_int_from_ups(CI_STATUS, &val);
+   (void)read_int_from_ups(CI_STATUS, &val);
 
    Dmsg(200, "Leave usb_ups_kill_power\n");
    return hibernate;
