@@ -20,8 +20,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 #include "apc.h"
@@ -105,13 +105,13 @@ int execute_command(UPSINFO *ups, UPSCOMMANDS cmd)
    if (g_os_version_info.dwPlatformId == VER_PLATFORM_WIN32_WINDOWS) {
       /* Win95/98/ME need environment size parameter and no extra quotes */
       asnprintf(cmdline, sizeof(cmdline), 
-         "\"%s\" /E:4096 /c \"%s%s\" %s %s %d %d \"%s\"",
+         "\"%s\" /E:4096 /c \"%s%s\" %s \"%s\" %d %d \"%s\"",
          comspec, ups->scriptdir, APCCONTROL_FILE, cmd.command,
          ups->upsname, !ups->is_slave(), ups->is_plugged(), sbindir);
    } else {
       /* WinNT/2K/Vista need quotes around the entire sub-command */
       asnprintf(cmdline, sizeof(cmdline), 
-         "\"%s\" /c \"\"%s%s\" %s %s %d %d \"%s\"\"",
+         "\"%s\" /c \"\"%s%s\" %s \"%s\" %d %d \"%s\"\"",
          comspec, ups->scriptdir, APCCONTROL_FILE, cmd.command,
          ups->upsname, !ups->is_slave(), ups->is_plugged(), sbindir);
    }
