@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 #include "apc.h"
@@ -40,7 +40,7 @@ int make_file(UPSINFO *ups, const char *path)
 {
    int makefd;
 
-   if ((makefd = open(path, O_CREAT | O_WRONLY, 0644)) >= 0) {
+   if ((makefd = open(path, O_CREAT | O_WRONLY | O_CLOEXEC, 0644)) >= 0) {
       close(makefd);
    } else {
       log_event(ups, LOG_ERR, "Unable to create %s: ERR=%s\n",
@@ -60,7 +60,7 @@ void make_pid_file(void)
    char buf[100];
 
    unlink(pidfile);
-   if ((pfd = open(pidfile, O_CREAT | O_TRUNC | O_WRONLY, 0644)) >= 0) {
+   if ((pfd = open(pidfile, O_CREAT | O_TRUNC | O_WRONLY | O_CLOEXEC, 0644)) >= 0) {
       len = asnprintf(buf, sizeof(buf), "%ld\n", (long)pid);
       write(pfd, buf, len);
       close(pfd);
