@@ -12,8 +12,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1335, USA.
  */
 
 #include "apc.h"
@@ -199,6 +199,8 @@ bool StatMgr::open()
       close();
 
    m_socket = net_open(m_host, NULL, m_port);
+   if (m_socket < 0)
+      m_socket = INVALID_SOCKET;
    return m_socket != INVALID_SOCKET;
 }
 
