@@ -26,24 +26,20 @@
  * SUCH DAMAGE.
  */
 
-#include <sys/cdefs.h>
-
 #include <assert.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/time.h>
 
-#include <dev/usb/usb.h>
-#include <dev/usb/usbhid.h>
-
 #include "usbhid.h"
 #include "usbvar.h"
+#include "usbcompat.h"
 
 #define MAXUSAGE 100
 struct hid_data {
-	u_char *start;
-	u_char *end;
-	u_char *p;
+	unsigned char *start;
+   unsigned char *end;
+   unsigned char *p;
 	hid_item_t cur;
 	unsigned int usages[MAXUSAGE];
 	int nusage;
@@ -59,7 +55,7 @@ struct hid_data {
 	 * it until we know the ID.
 	 */
 	hid_item_t savedcoll;
-	u_char hassavedcoll;
+   unsigned char hassavedcoll;
 	/*
 	 * Absolute data position (bits) for input/output/feature.
 	 *  Assumes that hid_input, hid_output and hid_feature have
@@ -158,9 +154,9 @@ hid_get_item_raw(hid_data_t s, hid_item_t *h)
 		REPORT_SAVED_COLL;
 		if (c->logical_minimum >= c->logical_maximum) {
 			if (s->logminsize == 1)
-				c->logical_minimum =(int8_t)c->logical_minimum;
+				c->logical_minimum =(signed char)c->logical_minimum;
 			else if (s->logminsize == 2)
-				c->logical_minimum =(int16_t)c->logical_minimum;
+				c->logical_minimum =(signed short)c->logical_minimum;
 		}
 		if (s->multi < s->multimax) {
 			c->usage = s->usages[min(s->multi, s->nusage-1)];
@@ -320,7 +316,7 @@ hid_get_item_raw(hid_data_t s, hid_item_t *h)
 				c->logical_maximum = dval;
 				break;
 			case 3:
-				c->physical_maximum = dval;
+				c->physical_minimum = dval;
 				break;
 			case 4:
 				c->physical_maximum = dval;
